Errors (`pyhmmer.errors`)
=========================

.. currentmodule:: pyhmmer.errors

.. automodule:: pyhmmer.errors


Memory Errors
-------------

.. autosummary::

   AllocationError

.. toctree::
    :hidden:
    :caption: Memory Errors

    Memory Errors <mem>


Value Errors
------------

.. autosummary::

   AlphabetMismatch
   MissingCutoffs
   InvalidHMM
   InvalidParameter

.. toctree::
    :hidden:
    :caption: Memory Errors

    Value Errors <value>


Runtime Errors
--------------

.. autosummary::

   UnexpectedError
   EaselError
   ServerError

.. toctree::
    :hidden:
    :caption: Runtime Errors

    Runtime Errors <runtime>
